@@ -11,10 +11,11 @@ import struct
 import time
 from collections.abc import Callable
 from dataclasses import dataclass, field
+from enum import StrEnum
 from typing import Any
 
-from roborock.containers import RRiot
-from roborock.exceptions import RoborockException
+from roborock.data import RRiot
+from roborock.exceptions import RoborockException, RoborockUnsupportedFeature
 from roborock.protocol import Utils
 from roborock.roborock_message import RoborockMessage, RoborockMessageProtocol
 from roborock.roborock_typing import RoborockCommand
@@ -32,6 +33,13 @@ CommandType = RoborockCommand | str
 ParamsType = list | dict | int | None
 
 
+class LocalProtocolVersion(StrEnum):
+    """Supported local protocol versions. Different from vacuum protocol versions."""
+
+    L01 = "L01"
+    V1 = "1.0"
+
+
 @dataclass(frozen=True, kw_only=True)
 class SecurityData:
     """Security data included in the request for some V1 commands."""
@@ -153,11 +161,11 @@ def decode_rpc_response(message: RoborockMessage) -> ResponseMessage:
         _LOGGER.debug("Decoded V1 message result: %s", result)
         if isinstance(result, str):
             if result == "unknown_method":
-                exc = RoborockException("The method called is not recognized by the device.")
+                exc = RoborockUnsupportedFeature("The method called is not recognized by the device.")
             elif result != "ok":
                 exc = RoborockException(f"Unexpected API Result: {result}")
             result = {}
-        if not isinstance(result, (dict, list, int)):
+        if not isinstance(result, dict | list | int):
             raise RoborockException(
                 f"Invalid V1 message format: 'result' was unexpected type {type(result)}. {message.payload!r}"
             )
